### Repo

Contains data processing methods for ADL datasets.

### Motivation

### Supported Datasets
  - Casas Aruba (2011)
  - Casas Milan (2009)
  - Aras
  - Amsterdam 
  - MitLab

### Replication list


### Reading list

- LSTMS
- HMMs
 

### TODO liste
 - check out projects like skorch, paladium